.. _id.appendix.test_domain:

Testing Domains
==============================================================================

Behave and other BDD frameworks allow you to provide **step libraries**
to reuse step definitions in similar projects that address the same 
problem domain.

Support of the following testing domains is currently known:

=============== ================= =========================================================
Testing Domain   Name              Description
=============== ================= =========================================================
Command-line    `behave4cmd`_     Test command-line tools, like behave, etc. (coming soon).
Web Apps        `django-behave`_  Test Django Web apps with behave.
Web, SMS, ...   `behaving`_       Test Web Apps, Email, SMS, Personas (step library).
=============== ================= =========================================================

.. _behave4cmd: https://github.com/jenisys/behave4cmd
.. _django-behave: https://github.com/rwillmer/django-behave
.. _behaving: https://github.com/ggozad/behaving
